@@ -43,18 +43,14 @@ vcgClost <- function(x,mesh,sign=TRUE,barycentric=FALSE, smoothNormals=FALSE, bo
     {
         if (!inherits(mesh,"mesh3d"))
             stop("argument 'mesh' needs to be object of class 'mesh3d'")
+        mesh <- meshintegrity(mesh,facecheck=TRUE)
         vb <- mesh$vb[1:3,,drop=FALSE]
-        if (!is.matrix(vb))
-            stop("target mesh has no vertices")
-        if (!is.matrix(mesh$it))
-            stop("target mesh needs at least some faces")
         it <- mesh$it - 1
         dimit <- dim(it)[2]
         dimvb <- dim(vb)[2]
-        storage.mode(it) <- "integer"
-
+        
         if (is.matrix(x)) {
-            clost <- t(x)
+            clost <- t(x[,1:3])
             x <- list()
             x$vb <- clost
             class(x) <- "mesh3d"
